@@ -27,6 +27,10 @@
  * See the ChangeLog files for a list of changes. 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
 
@@ -121,8 +125,6 @@ get_dialog ()
 		gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog),
 				window);
 	
-		gtk_widget_grab_focus (dialog->dialog);
-
 		if (!GTK_WIDGET_VISIBLE (dialog->dialog))
 			gtk_widget_show (dialog->dialog);
 
@@ -151,7 +153,7 @@ get_dialog ()
 
 	/* Add the update button */
 	gedit_dialog_add_button (GTK_DIALOG (dialog->dialog), 
-				 _("Update"), GTK_STOCK_REFRESH, GTK_RESPONSE_OK);
+				 _("_Update"), GTK_STOCK_REFRESH, GTK_RESPONSE_OK);
 
 	content			= glade_xml_get_widget (gui, "docinfo_dialog_content");
 
@@ -177,11 +179,11 @@ get_dialog ()
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GTK_RESPONSE_OK);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect (G_OBJECT (dialog->dialog), "destroy",
+			   G_CALLBACK (dialog_destroyed), &dialog);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
-			   GTK_SIGNAL_FUNC (dialog_response_handler), dialog);
+	g_signal_connect (G_OBJECT (dialog->dialog), "response",
+			   G_CALLBACK (dialog_response_handler), dialog);
 
 	g_object_unref (gui);
 
