@@ -27,6 +27,10 @@
  * See the ChangeLog files for a list of changes. 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
 
@@ -183,11 +187,11 @@ get_dialog ()
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GTK_RESPONSE_OK);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect (G_OBJECT (dialog->dialog), "destroy",
+			   G_CALLBACK (dialog_destroyed), &dialog);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
-			   GTK_SIGNAL_FUNC (dialog_response_handler), dialog);
+	g_signal_connect (G_OBJECT (dialog->dialog), "response",
+			   G_CALLBACK (dialog_response_handler), dialog);
 
 	g_object_unref (gui);
 
@@ -414,7 +418,7 @@ init (GeditPlugin *pd)
 	gedit_debug (DEBUG_PLUGINS, "");
      
 	pd->name = _("Shell output");
-	pd->desc = _("Exucute a program and insert its output in the current document at the current "
+	pd->desc = _("Execute a program and insert its output in the current document at the current "
 		     "cursor position");
 	pd->author = "Paolo Maggi <maggi@athena.polito.it>";
 	pd->copyright = _("Copyright (C) 2002 - Paolo Maggi");
