@@ -22,6 +22,10 @@
  * Author: Paolo Maggi 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "bonobo-mdi.h"
 
 #include <bonobo/bonobo-i18n.h>
@@ -29,6 +33,8 @@
 #include <bonobo/bonobo-dock-layout.h>
 #include <bonobo/bonobo-ui-util.h>
 
+#include "gedit-debug.h"
+
 #include <string.h>
 
 #define BONOBO_MDI_KEY "BonoboMDI"
@@ -1239,7 +1245,8 @@ static void app_create (BonoboMDI *mdi, gchar *layout_string)
 	/* Create Container: */
  	ui_container = bonobo_window_get_ui_container (bw);
 
-	config_path = g_strdup_printf ("/%s/UIConfig/kvps/", mdi->priv->mdi_name);
+	config_path = g_strdup_printf ("/%s/UIConfig/kvps", mdi->priv->mdi_name);
+
   	bonobo_ui_engine_config_set_path (bonobo_window_get_ui_engine (bw),
                                      config_path);
 	g_free (config_path);
@@ -1440,12 +1447,7 @@ bonobo_mdi_add_view (BonoboMDI *mdi, BonoboMDIChild *child)
 		gtk_widget_show (GTK_WIDGET (mdi->priv->active_window));
 	}
 
-	/* this reference will compensate the view's unrefing
-	   when removed from its parent later, as we want it to
-	   stay valid until removed from the child with a call
-	   to bonobo_mdi_child_remove_view() */
-	gtk_widget_ref (view);
-
+	
 	if (!GTK_WIDGET_VISIBLE (view))
 		gtk_widget_show (view);
 
@@ -1477,8 +1479,16 @@ bonobo_mdi_add_view (BonoboMDI *mdi, BonoboMDIChild *child)
 
 				bonobo_window_set_contents (mdi->priv->active_window, view);
 				app_set_view (mdi, mdi->priv->active_window, view);
+
 			}
 
+	/* this reference will compensate the view's unrefing
+	   when removed from its parent later, as we want it to
+	   stay valid until removed from the child with a call
+	   to bonobo_mdi_child_remove_view() */
+	g_object_ref (G_OBJECT (view));
+	gtk_object_sink (GTK_OBJECT (view));
+
 	g_object_set_data (G_OBJECT (view), BONOBO_MDI_CHILD_KEY, child);
 	
 	return TRUE;
@@ -1599,6 +1609,8 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 	BonoboWindow *window;
 	BonoboMDIChild *child;
 	gint ret = TRUE;
+
+	gedit_debug (DEBUG_MDI, "");
 	
 	g_return_val_if_fail (mdi != NULL, FALSE);
 	g_return_val_if_fail (BONOBO_IS_MDI (mdi), FALSE);
@@ -1620,8 +1632,12 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 
 	window = bonobo_mdi_get_window_from_view (view);
 
+	gedit_debug (DEBUG_MDI, "BU");
+
 	gtk_container_remove (GTK_CONTAINER (parent), view);
 
+	gedit_debug (DEBUG_MDI, "AU");
+
 	if (view == mdi->priv->active_view)
 	   mdi->priv->active_view = NULL;
 
@@ -1679,6 +1695,8 @@ bonobo_mdi_remove_view (BonoboMDI *mdi, GtkWidget *view, gint force)
 	if(mdi->priv->mode != BONOBO_MDI_MODAL)
 		bonobo_mdi_child_remove_view (child, view);
 
+	gedit_debug (DEBUG_MDI, "END");
+
 	return TRUE;
 }
 
@@ -1755,6 +1773,8 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 	GList *view_node;
 	GtkWidget *view;
 
+	gedit_debug (DEBUG_MDI, "");
+	
 	g_return_val_if_fail (mdi != NULL, FALSE);
 	g_return_val_if_fail (BONOBO_IS_MDI (mdi), FALSE);
 	g_return_val_if_fail (child != NULL, FALSE);
@@ -1762,6 +1782,7 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 
 	/* if force is set to TRUE, don't call the remove_child handler (ie there is no way for the
 	   user to stop removal of the child) */
+
 	if (!force)
 		g_signal_emit (G_OBJECT (mdi), mdi_signals [REMOVE_CHILD], 0, child, &ret);
 
@@ -1779,6 +1800,7 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 
 	mdi->priv->children = g_list_remove (mdi->priv->children, child);
 
+
 	child_list_menu_remove_item (mdi, child);
 
 	if (child == mdi->priv->active_child)
@@ -1789,8 +1811,10 @@ bonobo_mdi_remove_child (BonoboMDI *mdi, BonoboMDIChild *child, gint force)
 	g_signal_handlers_disconnect_by_func (GTK_OBJECT (child), 
 			GTK_SIGNAL_FUNC (child_name_changed), mdi);
 
+
 	g_object_unref (G_OBJECT (child));
 
+
 	if (mdi->priv->mode == BONOBO_MDI_MODAL && mdi->priv->children) 
 	{
 		BonoboMDIChild *next_child = mdi->priv->children->data;
@@ -2446,11 +2470,11 @@ bonobo_mdi_construct (BonoboMDI *mdi, gchar* name, gchar* title, GtkPositionType
 	g_return_if_fail (mdi->priv->mdi_name == NULL);
 	g_return_if_fail (mdi->priv->title == NULL);
 
-	if (name != NULL)
-		mdi->priv->mdi_name = g_strdup (name);
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (title != NULL);
 
-	if (title != NULL)
-		mdi->priv->title = g_strdup (title);
+	mdi->priv->mdi_name = g_strdup (name);
+	mdi->priv->title = g_strdup (title);
 
 	mdi->priv->tab_pos = tab_pos;
 }
