@@ -207,14 +207,14 @@ static CategoriesTreeItem user_interface [] =
 static CategoriesTreeItem editor_behavior [] =
 {
 	{_("Font & Colors"), NULL, FONT_COLORS_SETTINGS},
-	
- 	{_("Save"), NULL, SAVE_SETTINGS },
-/*
+
 	{_("Tabs"), NULL, TABS_SETTINGS},
-*/	
-	{_("Undo"), NULL, UNDO_SETTINGS},
 	{_("Wrap mode"), NULL, WRAP_MODE_SETTINGS},
 	{_("Line numbers"), NULL , LINE_NUMBERS_SETTINGS},
+	
+ 	{_("Save"), NULL, SAVE_SETTINGS },
+	{_("Undo"), NULL, UNDO_SETTINGS},
+
 
 	{ NULL }
 };
@@ -234,26 +234,30 @@ static CategoriesTreeItem toplevel [] =
 	{ NULL }
 };
 
-GtkType
+GType
 gedit_preferences_dialog_get_type (void)
 {
-	static GtkType dialog_type = 0;
+	static GType dialog_type = 0;
 
 	if (!dialog_type)
     	{
-      		static const GtkTypeInfo dialog_info =
+      		static const GTypeInfo dialog_info =
       		{
-			"GeditPreferencesDialog",
-			sizeof (GeditPreferencesDialog),
 			sizeof (GeditPreferencesDialogClass),
-			(GtkClassInitFunc) gedit_preferences_dialog_class_init,
-			(GtkObjectInitFunc) gedit_preferences_dialog_init,
-			/* reserved_1 */ NULL,
-        		/* reserved_2 */ NULL,
-        		(GtkClassInitFunc) NULL,
+        		NULL,		/* base_init */
+        		NULL,		/* base_finalize */
+        		(GClassInitFunc) gedit_preferences_dialog_class_init,
+        		NULL,           /* class_finalize */
+        		NULL,           /* class_data */
+        		sizeof (GeditPreferencesDialog),
+        		0,              /* n_preallocs */
+        		(GInstanceInitFunc) gedit_preferences_dialog_init
       		};
 
-     		dialog_type = gtk_type_unique (GTK_TYPE_DIALOG, &dialog_info);
+     		dialog_type = g_type_register_static (GTK_TYPE_DIALOG,
+						      "GeditPreferencesDialog",
+						      &dialog_info, 
+						      0);
     	}
 
 	return dialog_type;
@@ -319,6 +323,8 @@ gedit_preferences_dialog_finalize (GObject *object)
 	g_return_if_fail (GEDIT_IS_PREFERENCES_DIALOG (dlg));
 	g_return_if_fail (dlg->priv != NULL);
 
+	g_object_unref (G_OBJECT (dlg->priv->categories_tree_model));
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
 	g_free (dlg->priv);
@@ -813,6 +819,8 @@ gedit_preferences_dialog_setup_font_and_colors_page (GeditPreferencesDialog *dlg
 			(dlg->priv->default_font_checkbutton), gedit_settings->use_default_font);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
 			(dlg->priv->default_colors_checkbutton), gedit_settings->use_default_colors);
+
+	return TRUE;
 }
 
 static void
@@ -1041,6 +1049,8 @@ gedit_preferences_dialog_setup_page_page (GeditPreferencesDialog *dlg, GladeXML
 	
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->line_numbers_checkbutton),
 				gedit_settings->print_line_numbers > 0);
+
+	return TRUE;
 }
 
 static gboolean 
@@ -1055,6 +1065,8 @@ gedit_preferences_dialog_setup_line_numbers_page (GeditPreferencesDialog *dlg, G
 	
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dlg->priv->display_line_numbers_checkbutton),
 				gedit_settings->show_line_numbers);
+
+	return TRUE;
 }
 
 gboolean 
@@ -1223,7 +1235,11 @@ gedit_preferences_dialog_update_settings (GeditPreferencesDialog *dlg)
 
 	gedit_settings->show_line_numbers = 
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-					      dlg->priv->display_line_numbers_checkbutton));	
+					      dlg->priv->display_line_numbers_checkbutton));
+
+	/* Tabs page */	
+	gedit_settings->tab_size =
+		gtk_spin_button_get_value (GTK_SPIN_BUTTON (dlg->priv->tabs_width_spinbutton));
 
 	return TRUE;
 	
