@@ -43,6 +43,7 @@
 #include "gedit-view.h"
 #include "gedit-file.h"
 #include "gedit-print.h"
+#include "gedit-prefs.h"
 #include "dialogs/gedit-dialogs.h"
 #include "dialogs/gedit-preferences-dialog.h"
 
@@ -53,8 +54,9 @@
 			                          GTK_MESSAGE_INFO,	\
 			                          GTK_BUTTONS_OK,	\
                                    		  _("Not yet implemented."));	\
-	                         gtk_dialog_run (GTK_DIALOG (message_dlg));	\
-  	                         gtk_widget_destroy (message_dlg); }
+				  gtk_dialog_set_default_response (GTK_DIALOG (message_dlg), GTK_RESPONSE_OK); \
+	                          gtk_dialog_run (GTK_DIALOG (message_dlg));	\
+  	                          gtk_widget_destroy (message_dlg); }
 
 void 
 gedit_cmd_file_new (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
@@ -137,8 +139,6 @@ gedit_cmd_file_open_uri (BonoboUIComponent *uic, gpointer user_data, const gchar
 void
 gedit_cmd_file_print (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
-	TO_BE_IMPLEMENTED
-/*		
 	GeditMDIChild *active_child;
 	
 	gedit_debug (DEBUG_COMMANDS, "");
@@ -147,16 +147,13 @@ gedit_cmd_file_print (BonoboUIComponent *uic, gpointer user_data, const gchar* v
 	if (active_child == NULL)
 		return;
 	
-	g_print ("***** Printing in gedit2 is completely broken. Please don't report bugs about it.\n");
 	gedit_print (active_child);
-*/
+
 }
 
 void
 gedit_cmd_file_print_preview (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
-	TO_BE_IMPLEMENTED
-/*
 	GeditMDIChild *active_child;
 	
 	gedit_debug (DEBUG_COMMANDS, "");
@@ -165,9 +162,7 @@ gedit_cmd_file_print_preview (BonoboUIComponent *uic, gpointer user_data, const
 	if (active_child == NULL)
 		return;
 	
-	g_print ("***** Printing in gedit2 is completely broken. Please don't report bugs about it.\n");
 	gedit_print_preview (active_child);
-*/
 }
 
 void 
@@ -181,8 +176,12 @@ gedit_cmd_file_close (BonoboUIComponent *uic, gpointer user_data, const gchar* v
 	
 	if (active_view == NULL)
 		return;
-
+	
+	gedit_close_x_button_pressed = TRUE;
+	
 	gedit_file_close (active_view);
+
+	gedit_close_x_button_pressed = FALSE;
 }
 
 void 
@@ -190,7 +189,11 @@ gedit_cmd_file_close_all (BonoboUIComponent *uic, gpointer user_data, const gcha
 {
 	gedit_debug (DEBUG_COMMANDS, "");
 
+	gedit_close_x_button_pressed = TRUE;
+	
 	gedit_file_close_all ();
+
+	gedit_close_x_button_pressed = FALSE;
 }
 
 void 
@@ -198,7 +201,11 @@ gedit_cmd_file_exit (BonoboUIComponent *uic, gpointer user_data, const gchar* ve
 {
 	gedit_debug (DEBUG_COMMANDS, "");
 
+	gedit_exit_button_pressed = TRUE;
+	
 	gedit_file_exit ();	
+
+	gedit_exit_button_pressed = FALSE;
 }
 
 void 
@@ -329,8 +336,12 @@ gedit_cmd_search_find_again (BonoboUIComponent *uic, gpointer user_data, const g
 				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_INFO,
 				GTK_BUTTONS_OK,
-				_("The searched string has not been found."));
-			
+				_("The string \"%s\" has not been found."), last_searched_text);
+
+			gtk_dialog_set_default_response (GTK_DIALOG (message_dlg), GTK_RESPONSE_OK);
+
+			gtk_window_set_resizable (GTK_WINDOW (message_dlg), FALSE);
+
 			gtk_dialog_run (GTK_DIALOG (message_dlg));
   			gtk_widget_destroy (message_dlg);
 		}
@@ -351,10 +362,7 @@ gedit_cmd_search_replace (BonoboUIComponent *uic, gpointer user_data, const gcha
 {
 	gedit_debug (DEBUG_COMMANDS, "");
 
-	TO_BE_IMPLEMENTED
-/*
 	gedit_dialog_replace ();
-*/
 }
 
 void 
@@ -365,12 +373,22 @@ gedit_cmd_search_goto_line (BonoboUIComponent *uic, gpointer user_data, const gc
 	gedit_dialog_goto_line ();
 }
 
+void 
+gedit_cmd_tools_plugin_manager (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
+{
+	gedit_debug (DEBUG_COMMANDS, "");
+
+	gedit_dialog_plugin_manager ();
+}
+
 void
 gedit_cmd_settings_preferences (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
 	GtkWidget *dlg;
 	gint ret;
 
+	gedit_debug (DEBUG_COMMANDS, "");
+
 	dlg = gedit_preferences_dialog_new (
 			GTK_WINDOW (bonobo_mdi_get_active_window (BONOBO_MDI (gedit_mdi))));
 
@@ -385,15 +403,41 @@ gedit_cmd_settings_preferences (BonoboUIComponent *uic, gpointer user_data, cons
 				{
 					gedit_mdi_update_ui_according_to_preferences (gedit_mdi);
 					gedit_prefs_save_settings ();
+
+					gtk_widget_hide (dlg);
+				}
+				else
+				{
+					GtkWidget *message_dlg;
+
+					message_dlg = gtk_message_dialog_new (
+						GTK_WINDOW (bonobo_mdi_get_active_window (
+								BONOBO_MDI (gedit_mdi))),
+						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						GTK_MESSAGE_ERROR,
+						GTK_BUTTONS_OK,
+						_("Impossible to update gedit settings."));
+
+					gtk_dialog_set_default_response (GTK_DIALOG (message_dlg), 
+							GTK_RESPONSE_OK);
+
+					gtk_window_set_resizable (GTK_WINDOW (message_dlg), FALSE);
+
+					gtk_dialog_run (GTK_DIALOG (message_dlg));
+  					gtk_widget_destroy (message_dlg);
 				}
 
 				break;
+								
 			case GTK_RESPONSE_HELP:
 				/* FIXME */
 				break;
+
+			default:
+				gtk_widget_hide (dlg);
 		}	
 		
-	} while (ret == GTK_RESPONSE_HELP);
+	} while (GTK_WIDGET_VISIBLE (dlg));
 
 	gtk_widget_destroy (dlg);
 }
@@ -401,35 +445,73 @@ gedit_cmd_settings_preferences (BonoboUIComponent *uic, gpointer user_data, cons
 void 
 gedit_cmd_help_about (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
-	/* FIXME */
-	static const char *authors[] = { "Chema Celorio", 
-					 "Paolo Maggi", 
-					  NULL };
+	/* TODO: add logo -- Paolo */
+	/* FIXME: set window position at the center of the active window -- Paolo */
+
+	static GtkWidget *about = NULL;
+	GdkPixbuf* pixbuf = NULL;
 	
-	static const char *documentors[] = { "Eric Baudais", NULL };
+	gchar *authors[] = {
+		"Paolo Maggi <maggi@athena.polito.it>",
+		"Chema Celorio <chema@ximian.com>", 
+		"James Willcox <jwillcox@cs.indiana.edu>",
+		NULL
+	};
 	
-	GtkWidget *about_box = NULL;
+	gchar *documenters[] = {
+		"Eric Baudais <baudais@okstate.edu>",
+		NULL
+	};
 	
+	/* Translator credits */
+	/*
+	gchar *translator_credits = _("");
+	*/
+
 	gedit_debug (DEBUG_COMMANDS, "");
+
+	if (about != NULL)
+	{
+		gdk_window_show (about->window);
+		gdk_window_raise (about->window);
+		return;
+	}
 	
-	g_print ("****** About box in gedit2 is completely broken. Please don't report bugs about it.\n");
+	pixbuf = gdk_pixbuf_new_from_file ( GNOME_ICONDIR "/gedit-logo.png", NULL);
+	if (pixbuf != NULL)
+	{
+		GdkPixbuf* temp_pixbuf = NULL;
 
-	about_box = gnome_about_new ("gedit",
-				VERSION,
-				"(c) 1998-2000 Alex Robert and Ewan Lawrence\n"
-				"(c) 2000-2001 Chema Celorio and Paolo Maggi",
-				"gedit is a small and lightweight text editor for GNOME",
-				authors,
-				documentors,
-				NULL /*"Translation credits"*/,
-				NULL /* logo pixbuf */);
+		temp_pixbuf = gdk_pixbuf_scale_simple (pixbuf, 
+					 gdk_pixbuf_get_width (pixbuf) / 2,
+					 gdk_pixbuf_get_height (pixbuf) / 2,
+					 GDK_INTERP_HYPER);
+		g_object_unref (pixbuf);
 
+		pixbuf = temp_pixbuf;
+	}
 
-	gtk_window_set_transient_for (GTK_WINDOW (about_box),
-			      GTK_WINDOW (bonobo_mdi_get_active_window (BONOBO_MDI (gedit_mdi))));
+	about = gnome_about_new (_("gedit"), VERSION,
+				"(C) 1998-2000 Evan Lawrence and Alex Robert\n"
+				"(C) 2000-2002 Chema Celorio and Paolo Maggi",
+				_("gedit is a small and lightweight text editor for Gnome"),
+				(const char **)authors,
+				(const char **)documenters,
+				NULL, /*(const char *)translator_credits,*/
+				pixbuf);
 
-	gtk_dialog_run (GTK_DIALOG (about_box));
+	gtk_window_set_transient_for (GTK_WINDOW (about),
+			GTK_WINDOW (gedit_get_active_window ()));
 
-	gtk_widget_destroy (about_box);
+	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
+
+	if (pixbuf != NULL)
+		g_object_unref (pixbuf);
+	
+	g_signal_connect (G_OBJECT (about), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &about);
+	
+	gtk_widget_show (about);
 }
 
+
