@@ -28,6 +28,10 @@
  * See the ChangeLog files for a list of changes. 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libgnome/libgnome.h>
 #include <libgnomevfs/gnome-vfs.h>
 
@@ -41,7 +45,8 @@
 #include "gedit-debug.h"
 #include "gedit-utils.h"
 #include "gedit-undo-manager.h"
-  
+
+#include "gedit-marshal.h"
 
 #define NOT_EDITABLE_TAG_NAME "not_editable_tag"
 
@@ -173,7 +178,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, name_changed),
 			      NULL, NULL,
-			      gtk_marshal_VOID__VOID,
+			      gedit_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 	
@@ -183,7 +188,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, loaded),
 			      NULL, NULL,
-			      gtk_marshal_VOID__VOID,
+			      gedit_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 	
@@ -193,7 +198,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, saved),
 			      NULL, NULL,
-			      gtk_marshal_VOID__VOID,
+			      gedit_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
 
@@ -203,7 +208,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, readonly_changed),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -214,7 +219,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, can_undo),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -225,7 +230,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, can_redo),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -837,6 +842,27 @@ gedit_document_save_as (GeditDocument* doc, const gchar *uri, GError **error)
 	return ret;
 }
 
+gboolean	
+gedit_document_save_a_copy_as (GeditDocument* doc, const gchar *uri, GError **error)
+{
+	gboolean m;
+	gboolean ret;
+
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_val_if_fail (doc != NULL, FALSE);
+	g_return_val_if_fail (doc->priv != NULL, FALSE);
+	g_return_val_if_fail (uri != NULL, FALSE);
+	
+	m = gedit_document_get_modified (doc);
+
+	ret = gedit_document_save_as_real (doc, uri, FALSE, error);
+	
+	gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc), m);	 
+
+	return ret;
+}
+
 static gboolean	
 gedit_document_save_as_real (GeditDocument* doc, const gchar *uri,
 	       gboolean create_backup_copy, GError **error)
@@ -1534,3 +1560,32 @@ gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset)
 	return gtk_text_iter_get_line (&iter);
 }
 
+gint gedit_document_get_cursor (GeditDocument *doc)
+{
+	GtkTextIter iter;
+	
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
+
+	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (doc),			
+                                    &iter,
+                                    gtk_text_buffer_get_mark (GTK_TEXT_BUFFER (doc),
+					                      "insert"));
+
+	return gtk_text_iter_get_offset (&iter); 
+}
+
+void
+gedit_document_set_cursor (GeditDocument *doc, gint cursor)
+{
+	GtkTextIter iter;
+	
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+	
+	/* Place the cursor at the requested position */
+	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &iter, cursor);
+	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
+}
