@@ -81,8 +81,8 @@ struct _GeditDocumentClass
 
 };
 
-#define GEDIT_DOCUMENT_IO_ERROR gedit_document_io_error_quark()
-GQuark 		gedit_document_io_error_quark();
+#define GEDIT_DOCUMENT_IO_ERROR gedit_document_io_error_quark ()
+GQuark 		gedit_document_io_error_quark (void);
 
 GType        	gedit_document_get_type      	(void) G_GNUC_CONST;
 
@@ -105,6 +105,9 @@ gboolean	gedit_document_save 		(GeditDocument* doc, GError **error);
 gboolean	gedit_document_save_as 		(GeditDocument* doc, 
 						 const gchar *uri, GError **error);
 
+gboolean	gedit_document_save_a_copy_as 	(GeditDocument* doc, 
+						 const gchar *uri, GError **error);
+
 gboolean 	gedit_document_revert 		(GeditDocument *doc,  GError **error);
 
 gboolean	gedit_document_is_untitled 	(const GeditDocument* doc);
@@ -125,6 +128,9 @@ void		gedit_document_insert_text_at_cursor (GeditDocument *doc,
                                                  const gchar   *text,
                                                  gint           len);
 
+gint		gedit_document_get_cursor (GeditDocument *doc);
+void		gedit_document_set_cursor (GeditDocument *doc, gint cursor);
+
 void 		gedit_document_delete_text 	(GeditDocument *doc, 
 		                                 gint start, gint end);
 
