@@ -30,10 +30,12 @@
 
 #include <glib.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "gedit-undo-manager.h"
 #include "gedit-debug.h"
 #include "gedit-prefs.h"
+#include "gedit-marshal.h"
 
 typedef struct _GeditUndoAction  		GeditUndoAction;
 typedef struct _GeditUndoInsertAction		GeditUndoInsertAction;
@@ -54,6 +56,7 @@ struct _GeditUndoInsertAction
 	gint   pos; 
 	gchar *text;
 	gint   length;
+	gint   chars;
 };
 
 struct _GeditUndoDeleteAction
@@ -119,7 +122,7 @@ static void gedit_undo_manager_check_list_size 		(GeditUndoManager *um);
 
 static gboolean gedit_undo_manager_merge_action 	(GeditUndoManager *um, 
 		                                         GeditUndoAction *undo_action);
-static guint gedit_undo_manager_get_number_of_groups 	(GeditUndoManager *um);
+static gint gedit_undo_manager_get_number_of_groups 	(GeditUndoManager *um);
 
 static GObjectClass 	*parent_class 				= NULL;
 static guint 		undo_manager_signals [LAST_SIGNAL] 	= { 0 };
@@ -171,7 +174,7 @@ gedit_undo_manager_class_init (GeditUndoManagerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditUndoManagerClass, can_undo),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -182,7 +185,7 @@ gedit_undo_manager_class_init (GeditUndoManagerClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditUndoManagerClass, can_redo),
 			      NULL, NULL,
-			      gtk_marshal_VOID__BOOLEAN,
+			      gedit_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_BOOLEAN);
@@ -348,15 +351,14 @@ gedit_undo_manager_undo (GeditUndoManager *um)
 					um->priv->document, 
 					undo_action->action.delete.start, 
 					undo_action->action.delete.text,
-					abs (undo_action->action.delete.end - 
-						undo_action->action.delete.start));
+					strlen (undo_action->action.delete.text));
 				break;
 			case GEDIT_UNDO_ACTION_INSERT:
 				gedit_document_delete_text (
 					um->priv->document, 
 					undo_action->action.insert.pos, 
 					undo_action->action.insert.pos + 
-						undo_action->action.insert.length); 
+						undo_action->action.insert.chars); 
 				break;
 
 			default:
@@ -374,7 +376,7 @@ gedit_undo_manager_undo (GeditUndoManager *um)
 		g_signal_emit (G_OBJECT (um), undo_manager_signals [CAN_REDO], 0, TRUE);
 	}
 
-	if (um->priv->next_redo >= (g_list_length (um->priv->actions) - 1))
+	if (um->priv->next_redo >= (gint)(g_list_length (um->priv->actions) - 1))
 	{
 		um->priv->can_undo = FALSE;
 		g_signal_emit (G_OBJECT (um), undo_manager_signals [CAN_UNDO], 0, FALSE);
@@ -489,13 +491,17 @@ gedit_undo_manager_insert_text_handler (GtkTextBuffer *buffer, GtkTextIter *pos,
 	if (um->priv->running_not_undoable_actions > 0)
 		return;
 
+	g_return_if_fail (strlen (text) == (guint)length);
+	
 	undo_action.action_type = GEDIT_UNDO_ACTION_INSERT;
 
 	undo_action.action.insert.pos    = gtk_text_iter_get_offset (pos);
 	undo_action.action.insert.text   = g_strdup (text);
 	undo_action.action.insert.length = length;
+	undo_action.action.insert.chars  = g_utf8_strlen (text, length);
+
+	if ((undo_action.action.insert.chars > 1) || (g_utf8_get_char (text) == '\n'))
 
-	if ((length > 1) || (*text == '\n'))
 	       	undo_action.mergeable = FALSE;
 	else
 		undo_action.mergeable = TRUE;
@@ -516,6 +522,8 @@ gedit_undo_manager_delete_range_handler (GtkTextBuffer *buffer, GtkTextIter *sta
 
 	undo_action.action_type = GEDIT_UNDO_ACTION_DELETE;
 
+	gtk_text_iter_order (start, end);
+
 	undo_action.action.delete.start  = gtk_text_iter_get_offset (start);
 	undo_action.action.delete.end    = gtk_text_iter_get_offset (end);
 
@@ -523,12 +531,17 @@ gedit_undo_manager_delete_range_handler (GtkTextBuffer *buffer, GtkTextIter *sta
 						GEDIT_DOCUMENT (buffer),
 						undo_action.action.delete.start,
 						undo_action.action.delete.end);
-	
-	if ((undo_action.action.delete.end - undo_action.action.delete.start) > 1)
+
+	if (((undo_action.action.delete.end - undo_action.action.delete.start) > 1) ||
+	     (g_utf8_get_char (undo_action.action.delete.text  ) == '\n'))
 	       	undo_action.mergeable = FALSE;
 	else
 		undo_action.mergeable = TRUE;
 
+	gedit_debug (DEBUG_UNDO, "START: %d", undo_action.action.delete.start);
+	gedit_debug (DEBUG_UNDO, "END: %d", undo_action.action.delete.end);
+	gedit_debug (DEBUG_UNDO, "TEXT: %s", undo_action.action.delete.text);
+
 	gedit_undo_manager_add_action (um, undo_action);
 }
 
@@ -641,10 +654,10 @@ gedit_undo_manager_check_list_size (GeditUndoManager *um)
 	g_return_if_fail (GEDIT_IS_UNDO_MANAGER (um));
 	g_return_if_fail (um->priv != NULL);
 	
-	if (settings->undo_levels < 1)
+	if (gedit_settings->undo_levels < 1)
 		return;
 
-	if (gedit_undo_manager_get_number_of_groups (um) > settings->undo_levels)
+	if (gedit_undo_manager_get_number_of_groups (um) > gedit_settings->undo_levels)
 	{
 		GeditUndoAction *undo_action;
 		GList* last;
@@ -670,7 +683,8 @@ gedit_undo_manager_check_list_size (GeditUndoManager *um)
 			undo_action = (GeditUndoAction*) last->data;
 
 		} while ((undo_action->order_in_group > 1) || 
-			 (gedit_undo_manager_get_number_of_groups (um) > settings->undo_levels));
+			 (gedit_undo_manager_get_number_of_groups (um) > 
+			  gedit_settings->undo_levels));
 	}	
 }
 
@@ -711,7 +725,7 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 	}
 
 	if (undo_action->action_type == GEDIT_UNDO_ACTION_DELETE)
-	{
+	{				
 		if ((last_action->action.delete.start != undo_action->action.delete.start) &&
 		    (last_action->action.delete.start != undo_action->action.delete.end))
 		{
@@ -724,12 +738,15 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 			gchar *str;
 			
 #define L  (last_action->action.delete.end - last_action->action.delete.start - 1)
-			
+#define g_utf8_get_char_at(p,i) g_utf8_get_char(g_utf8_offset_to_pointer((p),(i)))
+		
+			gedit_debug (DEBUG_UNDO, "L = %d", L);
+
 			/* Deleted with the delete key */
-			if ((undo_action->action.delete.text [0] != ' ') &&
-			    (undo_action->action.delete.text [0] != '\t') &&
-                            ((last_action->action.delete.text [L] == ' ') ||
-			     (last_action->action.delete.text [L] == '\t')))
+			if ((g_utf8_get_char (undo_action->action.delete.text) != ' ') &&
+			    (g_utf8_get_char (undo_action->action.delete.text) != '\t') &&
+                            ((g_utf8_get_char_at (last_action->action.delete.text, L) == ' ') ||
+			     (g_utf8_get_char_at (last_action->action.delete.text, L)  == '\t')))
 			{
 				last_action->mergeable = FALSE;
 				return FALSE;
@@ -739,7 +756,7 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 				undo_action->action.delete.text);
 			
 			g_free (last_action->action.delete.text);
-			last_action->action.delete.end += 1;
+			last_action->action.delete.end += (undo_action->action.delete.end - undo_action->action.delete.start);
 			last_action->action.delete.text = str;
 		}
 		else
@@ -747,10 +764,10 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 			gchar *str;
 			
 			/* Deleted with the backspace key */
-			if ((undo_action->action.delete.text [0] != ' ') &&
-			    (undo_action->action.delete.text [0] != '\t') &&
-                            ((last_action->action.delete.text [0] == ' ') ||
-			     (last_action->action.delete.text [0] == '\t')))
+			if ((g_utf8_get_char (undo_action->action.delete.text) != ' ') &&
+			    (g_utf8_get_char (undo_action->action.delete.text) != '\t') &&
+                            ((g_utf8_get_char (last_action->action.delete.text) == ' ') ||
+			     (g_utf8_get_char (last_action->action.delete.text) == '\t')))
 			{
 				last_action->mergeable = FALSE;
 				return FALSE;
@@ -767,13 +784,15 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 	else if (undo_action->action_type == GEDIT_UNDO_ACTION_INSERT)
 	{
 		gchar* str;
-
+		
+#define I (last_action->action.insert.chars - 1)
+		
 		if ((undo_action->action.insert.pos != 
-		     	(last_action->action.insert.pos + last_action->action.insert.length)) ||
-		    ((undo_action->action.insert.text [0] != ' ') &&
-		      (undo_action->action.insert.text [0] != '\t') &&
-		     ((last_action->action.insert.text [last_action->action.insert.length - 1] == ' ') ||
-		      (last_action->action.insert.text [last_action->action.insert.length - 1] == '\t')))
+		     	(last_action->action.insert.pos + last_action->action.insert.chars)) ||
+		    ((g_utf8_get_char (undo_action->action.insert.text) != ' ') &&
+		      (g_utf8_get_char (undo_action->action.insert.text) != '\t') &&
+		     ((g_utf8_get_char_at (last_action->action.insert.text, I) == ' ') ||
+		      (g_utf8_get_char_at (last_action->action.insert.text, I) == '\t')))
 		   )
 		{
 			last_action->mergeable = FALSE;
@@ -786,6 +805,8 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 		g_free (last_action->action.insert.text);
 		last_action->action.insert.length += undo_action->action.insert.length;
 		last_action->action.insert.text = str;
+		last_action->action.insert.chars += undo_action->action.insert.chars;
+
 	}
 	else
 		g_warning ("Unknown action inside undo merge encountered");	
@@ -793,11 +814,11 @@ gedit_undo_manager_merge_action (GeditUndoManager *um, GeditUndoAction *undo_act
 	return TRUE;
 }
 
-static guint
+static gint
 gedit_undo_manager_get_number_of_groups (GeditUndoManager *um)
 {
 	GList *list = um->priv->actions;
-  	guint num = 0;
+  	gint num = 0;
 
 	gedit_debug (DEBUG_UNDO, "");
   
