@@ -28,9 +28,7 @@
  * See the ChangeLog files for a list of changes. 
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
@@ -150,7 +148,6 @@ main (int argc, char **argv)
 	gint i;
 
 #ifdef ENABLE_NLS
-	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GEDIT_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
@@ -187,7 +184,7 @@ main (int argc, char **argv)
 	if (args)	
 		for (i = 0; args[i]; i++) 
 		{
-			if (strstr (args[i], "+")) 
+			if (*args[i] == '+') 
 				data->line_pos = atoi (args[i] + 1);		
 			else
 				data->file_list = g_list_append (data->file_list, args[i]);
@@ -196,7 +193,7 @@ main (int argc, char **argv)
 	/* Create gedit_mdi and open the first top level window */
 	gedit_mdi = gedit_mdi_new ();
 	bonobo_mdi_open_toplevel (BONOBO_MDI (gedit_mdi)); 
-	
+
 	gtk_init_add ((GtkFunction)gedit_load_file_list, (gpointer)data);
 
 	gtk_main();
@@ -206,7 +203,7 @@ main (int argc, char **argv)
 
 
 BonoboWindow*
-gedit_get_active_window ()
+gedit_get_active_window (void)
 {
 	g_return_val_if_fail (gedit_mdi != NULL, NULL);
 
@@ -214,7 +211,7 @@ gedit_get_active_window ()
 }
 
 GeditDocument*
-gedit_get_active_document ()
+gedit_get_active_document (void)
 {
 	BonoboMDIChild *active_child;
 
@@ -229,7 +226,7 @@ gedit_get_active_document ()
 }
 
 GeditView*
-gedit_get_active_view ()
+gedit_get_active_view (void)
 {
 	GtkWidget *active_view;
 
@@ -244,7 +241,7 @@ gedit_get_active_view ()
 }
 
 GList* 
-gedit_get_top_windows ()
+gedit_get_top_windows (void)
 {
 	g_return_val_if_fail (gedit_mdi != NULL, NULL);
 
@@ -259,4 +256,25 @@ gedit_get_ui_component_from_window (BonoboWindow* win)
 	return bonobo_mdi_get_ui_component_from_window (win);
 }
 
+/* Return a newly allocated list */
+GList*
+gedit_get_open_documents (void)
+{
+	GList* children;
+	GList* docs = NULL;
+	g_return_val_if_fail (gedit_mdi != NULL, NULL);
+
+	children = bonobo_mdi_get_children (BONOBO_MDI (gedit_mdi));
+
+	while (children != NULL)
+	{
+		GeditMDIChild *child;
+
+		child = GEDIT_MDI_CHILD (children->data);
+		
+		docs = g_list_append (docs, child->document);
+		children = g_list_next (children);
+	}
 	
+	return docs;
+}
